package com.me.pacman.entity;

import com.me.pacman.state.LevelState;

public abstract class MovableEntity extends Entity {

    // speed in tiles / second.
    public float speed;
    public Direction direction;
    public boolean moving;
    public boolean canMove = true;

    public MovableEntity(LevelState state, float x, float y, Direction direction, float speed, boolean moving) {
        super(state, x, y);
        this.speed = speed;
        this.direction = direction;
        this.moving = moving;
    }

    public void update(float dt) {
        if (!moving) {
            return;
        }

        float new_y = y;
        float new_x = x;

        switch (direction) {
            case NORTH:
                new_y += speed * dt;
                canMove = state.level.getComponent(new_x, new_y + 1f).isPassable();
                break;
            case EAST:
                new_x += speed * dt;
                canMove = state.level.getComponent(new_x + 1f,new_y).isPassable();
                break;
            case SOUTH:
                new_y -= speed * dt;
                canMove = state.level.getComponent(new_x, new_y - 1f).isPassable();
                break;
            case WEST:
                new_x -= speed * dt;
                canMove = state.level.getComponent(new_x - 1f,new_y).isPassable();
                break;
        }

        if (canMove) {
            x = new_x;
            y = new_y;
        } else {
            x = (int) new_x;
            y = (int) new_y;
        }

        super.update(dt);
    }

    public enum Direction {
        NORTH,
        EAST,
        SOUTH,
        WEST
    }

}
